/* -*- mode: c++ -*- */
/*
  MyServer
  strlcpy and strlcat by codingmaster
  Copyright (C) 2002, 2003, 2004, 2009, 2010, 2011 Free Software
  Foundation, Inc.
  Copyright (C) 2004 by codingmaster
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 3 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/
#include "myserver.h"
#ifndef SECURESTR_H
# define SECURESTR_H

unsigned int myserver_strlcat (char *destination, const char *source,
                               unsigned int size);

unsigned int myserver_strlcpy (char *destination, const char *source,
                               unsigned int size);
#endif


